summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorRussell Bryant <russell@russellbryant.com>2008-03-12 22:13:18 +0000
committerRussell Bryant <russell@russellbryant.com>2008-03-12 22:13:18 +0000
commit8bbef5f996078b5065cf54567b4af166186afb03 (patch)
tree8a8884d949ffae4bada2cff15af9b00b1cecb68e /include
parentff1527de3d1a0038754c90c6fa70668e7796f302 (diff)
Rename ast_tcptls_server_instance to session_instance, since this pertains to
server and client usage. git-svn-id: https://origsvn.digium.com/svn/asterisk/trunk@108295 65c4cc65-6c06-0410-ace0-fbb531ad65f3
Diffstat (limited to 'include')
-rw-r--r--include/asterisk/http.h2
-rw-r--r--include/asterisk/tcptls.h14
2 files changed, 8 insertions, 8 deletions
diff --git a/include/asterisk/http.h b/include/asterisk/http.h
index 320d5bc23..10e75d93e 100644
--- a/include/asterisk/http.h
+++ b/include/asterisk/http.h
@@ -65,7 +65,7 @@
content is specified)
\endverbatim
*/
-typedef struct ast_str *(*ast_http_callback)(struct ast_tcptls_server_instance *ser, const char *uri, struct ast_variable *params, int *status, char **title, int *contentlength);
+typedef struct ast_str *(*ast_http_callback)(struct ast_tcptls_session_instance *ser, const char *uri, struct ast_variable *params, int *status, char **title, int *contentlength);
/*! \brief Definition of a URI reachable in the embedded HTTP server */
struct ast_http_uri {
diff --git a/include/asterisk/tcptls.h b/include/asterisk/tcptls.h
index 814e433a1..004a883bc 100644
--- a/include/asterisk/tcptls.h
+++ b/include/asterisk/tcptls.h
@@ -102,7 +102,7 @@ struct ast_tls_config {
* or equivalent with a timeout of 'poll_timeout' milliseconds, and if the
* following accept() is successful it creates a thread in charge of
* running the session, whose body is desc->worker_fn(). The argument of
* worker_fn() is a struct ast_tcptls_server_instance, which contains the address
* of the other party, a pointer to desc, the file descriptors (fd) on which
* we can do a select/poll (but NOT IO/, and a FILE *on which we can do I/O.
* We have both because we want to support plain and SSL sockets, and
@@ -111,7 +111,7 @@ struct ast_tls_config {
*
* NOTE: in order to let other parts of asterisk use these services,
* we need to do the following:
* + move struct ast_tcptls_server_instance and struct server_args to
* a common header file, together with prototypes for
* server_start() and server_root().
*/
@@ -119,7 +119,7 @@ struct ast_tls_config {
/*! \brief
* describes a server instance
*/
-struct ast_tcptls_server_instance {
+struct ast_tcptls_session_instance {
FILE *f; /* fopen/funopen result */
int fd; /* the socket returned by accept() */
SSL *ssl; /* ssl state */
@@ -154,7 +154,7 @@ struct server_args {
#define LEN_T size_t
#endif
-struct ast_tcptls_server_instance *ast_tcptls_client_start(struct server_args *desc);
+struct ast_tcptls_session_instance *ast_tcptls_client_start(struct server_args *desc);
void *ast_tcptls_server_root(void *);
void ast_tcptls_server_start(struct server_args *desc);
@@ -163,14 +163,14 @@ int ast_ssl_setup(struct ast_tls_config *cfg);
void *ast_make_file_from_fd(void *data);
-HOOK_T ast_tcptls_server_read(struct ast_tcptls_server_instance *ser, void *buf, size_t count);
-HOOK_T ast_tcptls_server_write(struct ast_tcptls_server_instance *ser, void *buf, size_t count);
+HOOK_T ast_tcptls_server_read(struct ast_tcptls_session_instance *ser, void *buf, size_t count);
+HOOK_T ast_tcptls_server_write(struct ast_tcptls_session_instance *ser, void *buf, size_t count);
/*!
* \brief Destroy a server instance
*
* \return NULL for convenience
*/
-struct ast_tcptls_server_instance *ast_tcptls_server_instance_destroy(struct ast_tcptls_server_instance *i);
+struct ast_tcptls_session_instance *ast_tcptls_session_instance_destroy(struct ast_tcptls_session_instance *i);
#endif /* _ASTERISK_SERVER_H */
@@ -102,7 +102,7 @@ struct ast_tls_config {
* following accept() is successful it creates a thread in charge of
* running the session, whose body is desc->worker_fn(). The argument of
- * worker_fn() is a struct ast_tcptls_server_instance, which contains the address
+ * worker_fn() is a struct ast_tcptls_session_instance, which contains the address
* of the other party, a pointer to desc, the file descriptors (fd) on which
* we can do a select/poll (but NOT IO/, and a FILE *on which we can do I/O.
@@ -111,7 +111,7 @@ struct ast_tls_config {
* NOTE: in order to let other parts of asterisk use these services,
* we need to do the following:
- * + move struct ast_tcptls_server_instance and struct server_args to
+ * + move struct ast_tcptls_session_instance and struct server_args to
* a common header file, together with prototypes for
* server_start() and server_root().